==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAMRBaseParticlesReader.java <==
// java wrapper for vtkAMRBaseParticlesReader object
//

package vtk;
import vtk.*;

public class vtkAMRBaseParticlesReader extends vtkMultiBlockDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetFrequency_2();
  public int GetFrequency()
    { return GetFrequency_2(); }

  private native void SetFrequency_3(int id0);
  public void SetFrequency(int id0)
    { SetFrequency_3(id0); }

  private native long GetController_4();
  public vtkMultiProcessController GetController() {
    long temp = GetController_4();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetController_5(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_5(id0); }

  private native void SetFilterLocation_6(int id0);
  public void SetFilterLocation(int id0)
    { SetFilterLocation_6(id0); }

  private native int GetFilterLocation_7();
  public int GetFilterLocation()
    { return GetFilterLocation_7(); }

  private native void FilterLocationOn_8();
  public void FilterLocationOn()
    { FilterLocationOn_8(); }

  private native void FilterLocationOff_9();
  public void FilterLocationOff()
    { FilterLocationOff_9(); }

  private native long GetParticleDataArraySelection_10();
  public vtkDataArraySelection GetParticleDataArraySelection() {
    long temp = GetParticleDataArraySelection_10();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetNumberOfParticleArrays_11();
  public int GetNumberOfParticleArrays()
    { return GetNumberOfParticleArrays_11(); }

  private native String GetParticleArrayName_12(int id0);
  public String GetParticleArrayName(int id0)
    { return GetParticleArrayName_12(id0); }

  private native int GetParticleArrayStatus_13(String id0);
  public int GetParticleArrayStatus(String id0)
    { return GetParticleArrayStatus_13(id0); }

  private native void SetParticleArrayStatus_14(String id0,int id1);
  public void SetParticleArrayStatus(String id0,int id1)
    { SetParticleArrayStatus_14(id0,id1); }

  private native void SetFileName_15(String id0);
  public void SetFileName(String id0)
    { SetFileName_15(id0); }

  private native String GetFileName_16();
  public String GetFileName()
    { return GetFileName_16(); }

  private native void SetMinLocation_17(double id0,double id1,double id2);
  public void SetMinLocation(double id0,double id1,double id2)
    { SetMinLocation_17(id0,id1,id2); }

  private native void SetMaxLocation_18(double id0,double id1,double id2);
  public void SetMaxLocation(double id0,double id1,double id2)
    { SetMaxLocation_18(id0,id1,id2); }

  private native int GetTotalNumberOfParticles_19();
  public int GetTotalNumberOfParticles()
    { return GetTotalNumberOfParticles_19(); }

  public vtkAMRBaseParticlesReader() { super(); }

  public vtkAMRBaseParticlesReader(long id) { super(id); }

}

==> vtk-8.2.0-14-aarch64.pkg.tar.xz: vtk/vtkAMRBaseParticlesReader.java <==
// java wrapper for vtkAMRBaseParticlesReader object
//

package vtk;
import vtk.*;

public class vtkAMRBaseParticlesReader extends vtkMultiBlockDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetFrequency_2();
  public int GetFrequency()
    { return GetFrequency_2(); }

  private native void SetFrequency_3(int id0);
  public void SetFrequency(int id0)
    { SetFrequency_3(id0); }

  private native long GetController_4();
  public vtkMultiProcessController GetController() {
    long temp = GetController_4();

    if (temp == 0) return null;
    return (vtkMultiProcessController)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetController_5(vtkMultiProcessController id0);
  public void SetController(vtkMultiProcessController id0)
    { SetController_5(id0); }

  private native void SetFilterLocation_6(int id0);
  public void SetFilterLocation(int id0)
    { SetFilterLocation_6(id0); }

  private native int GetFilterLocation_7();
  public int GetFilterLocation()
    { return GetFilterLocation_7(); }

  private native void FilterLocationOn_8();
  public void FilterLocationOn()
    { FilterLocationOn_8(); }

  private native void FilterLocationOff_9();
  public void FilterLocationOff()
    { FilterLocationOff_9(); }

  private native long GetParticleDataArraySelection_10();
  public vtkDataArraySelection GetParticleDataArraySelection() {
    long temp = GetParticleDataArraySelection_10();

    if (temp == 0) return null;
    return (vtkDataArraySelection)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetNumberOfParticleArrays_11();
  public int GetNumberOfParticleArrays()
    { return GetNumberOfParticleArrays_11(); }

  private native String GetParticleArrayName_12(int id0);
  public String GetParticleArrayName(int id0)
    { return GetParticleArrayName_12(id0); }

  private native int GetParticleArrayStatus_13(String id0);
  public int GetParticleArrayStatus(String id0)
    { return GetParticleArrayStatus_13(id0); }

  private native void SetParticleArrayStatus_14(String id0,int id1);
  public void SetParticleArrayStatus(String id0,int id1)
    { SetParticleArrayStatus_14(id0,id1); }

  private native void SetFileName_15(String id0);
  public void SetFileName(String id0)
    { SetFileName_15(id0); }

  private native String GetFileName_16();
  public String GetFileName()
    { return GetFileName_16(); }

  private native void SetMinLocation_17(double id0,double id1,double id2);
  public void SetMinLocation(double id0,double id1,double id2)
    { SetMinLocation_17(id0,id1,id2); }

  private native void SetMaxLocation_18(double id0,double id1,double id2);
  public void SetMaxLocation(double id0,double id1,double id2)
    { SetMaxLocation_18(id0,id1,id2); }

  private native int GetTotalNumberOfParticles_19();
  public int GetTotalNumberOfParticles()
    { return GetTotalNumberOfParticles_19(); }

  public vtkAMRBaseParticlesReader() { super(); }

  public vtkAMRBaseParticlesReader(long id) { super(id); }

}
